@@ -16,7 +16,7 @@ import pandas as pd
 
 from nanocompare.global_config import set_log_debug_level, current_time_str
 
-NANOME_VERSION = "1.3.21"
+NANOME_VERSION = "1.3.23"
 
 # define the small error of 0 and 1, for fully-meth and unmeth eval
 EPSLONG = 1e-5
@@ -93,7 +93,7 @@ xgboost_mode_base_dir = os.path.join(Path(__file__).parent, 'xgboost', 'trained_
 
 nanome_model_dict = {
     "NA12878_XGBoostNA2T": 'NANOME_NA12878_train1.0_megalodon_deepsignal_XGBoostNA2T_model.pkl',
-    "NA12878_XGBoostNA3T": 'NANOME_NA12878_train1.0_nanopolish_megalodon_deepsignal_XGBoostNA3T_model.pkl',
+    "NA12878_XGBoostNA3T": 'NANOME_NA12878_train1.0_nanopolish_megalodon_deepsignal_XGBoostNA3T_niter10_model.pkl',
 }
 
 
